@@ -1,7 +1,9 @@
+mod boxart;
 mod brush;
 mod screen;
 mod stamp;
 
+pub use boxart::BoxArt;
 pub use brush::{Brush, Brushable};
 pub use screen::Screen;
 pub use stamp::Stamp;
\ No newline at end of file
