@@ -1,18 +1,21 @@
 #[derive(Clone, Copy, Debug)]
 pub struct CellContent {
-    pub fg: u8,
     pub bg: u8,
+    pub fg: u8,
 
     // 255: no bevel
     pub bevels: Bevels,
 
     pub sem: SemanticContent,
-    pub interactor: Interactor,
+    pub interactor: InteractorFmt, // interactor, mouseover color
+    pub scroll_interactor: Interactor,
 }
+
 #[derive(Clone, Copy, Debug)]
 pub enum SemanticContent {
     Blank,
     Small(u16), 
+    SmallPizza1(u16, u16), SmallPizza2(u16, u16), // two small tiles adjacent, divided by a diagonal line
 
     TopHalf(u16),
     BottomHalf(u16),
@@ -51,6 +54,24 @@ impl Interactor {
     // TODO: Create one with a specific ID
 }
 
+#[derive(Clone, Copy, Debug)]
+pub struct InteractorFmt {
+    pub interactor: Interactor,
+    pub bg: u8,
+    pub fg: u8,
+}
+
+impl InteractorFmt {
+    pub fn none() -> InteractorFmt { 
+        InteractorFmt {
+            interactor: Interactor::none(),
+            fg: 255,
+            bg: 255,
+        }
+    }
+}
+
+
 #[derive(Clone, Copy, Debug)]
 pub struct Bevels {
     // 255: no bevel
