@@ -1,12 +1,13 @@
 mod cell;
-mod font;
+pub(crate) mod font;
 mod renderer;
 mod sprite;
 #[allow(non_upper_case_globals)]
 pub mod colors;
 mod swatch;
 
-pub(crate) use cell::{Bevels, CellContent, Interactor, SemanticContent};
+pub(crate) use cell::{Bevels, CellContent, InteractorFmt};
+pub use cell::{Interactor, SemanticContent};
 pub use font::Font;
 pub(crate) use renderer::Render;
 pub(crate) use swatch::{DEFAULT_SWATCH, Swatch};
\ No newline at end of file
